package uraxis.programnodes;

import com.ur.urcap.api.contribution.ProgramNodeContribution;
import com.ur.urcap.api.contribution.program.ProgramAPIProvider;
import com.ur.urcap.api.domain.ProgramAPI;
import com.ur.urcap.api.domain.data.DataModel;
import com.ur.urcap.api.domain.script.ScriptWriter;
import com.ur.urcap.api.domain.undoredo.UndoRedoManager;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardInputCallback;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardInputFactory;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardNumberInput;
import uraxis.MyDaemonInstallationNodeContribution;

public class FestoNodeContribution implements ProgramNodeContribution {
    private final String VALUE="VALUE";
    private final ProgramAPI programAPI;
    private final UndoRedoManager undoRedoManager;
    private final KeyboardInputFactory keyboardFactory;

    private final FestoNodeView view;
    private final DataModel model;
    private final NodeType nodeType;

    public FestoNodeContribution(ProgramAPIProvider apiProvider, FestoNodeView view, DataModel model, NodeType nt) {
        this.programAPI = apiProvider.getProgramAPI();
        this.undoRedoManager = apiProvider.getProgramAPI().getUndoRedoManager();
        this.keyboardFactory = apiProvider.getUserInterfaceAPI().getUserInteraction().getKeyboardInputFactory();

        this.view = view;
        this.model = model;
        this.nodeType=nt;
    }

    @Override
    public void openView() {
        view.setValue(model.get(VALUE, 0));
    }

    @Override
    public void closeView() {
        model.set(VALUE, view.getValue());
    }

    @Override
    public String getTitle() {
        return "Festo "+ nodeType.name();
    }


    @Override
    public void generateScript(ScriptWriter writer) {
        if(nodeType==NodeType.ABS) {
            writer.appendLine(getInstallation().getXMLRPCVariable() + ".abs(\"" + view.getValue() + "\")");
            writer.appendLine("write_output_integer_register(3,"+view.getValue()+")");
        }
        else {
            writer.appendLine(getInstallation().getXMLRPCVariable() + ".rel(\"" + view.getValue() + "\")");
            writer.appendLine("write_output_integer_register(3," + view.getValue() + ")");
        }
        writer.writeChildren();

    }

    public KeyboardNumberInput getKeyboardForTextField() {
        KeyboardNumberInput<Integer> keyboardInput = keyboardFactory.createIntegerKeypadInput();
        keyboardInput.setInitialValue(0);
        return keyboardInput;
    }

    public KeyboardInputCallback<Integer> getCallbackForTextField() {
        return new KeyboardInputCallback<Integer>() {
            @Override
            public void onOk(Integer value) {
                view.setValue(value);
            }
        };
    }

    private MyDaemonInstallationNodeContribution getInstallation() {
        return programAPI.getInstallationNode(MyDaemonInstallationNodeContribution.class);
    }

    @Override
    public boolean isDefined() {
        return true;
    }
}
