package uraxis.programnodes;

import com.ur.urcap.api.contribution.ContributionProvider;
import com.ur.urcap.api.contribution.program.swing.SwingProgramNodeView;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardNumberInput;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

public class FestoNodeView implements SwingProgramNodeView<FestoNodeContribution>{

    private final Style style;
    private JTextField jTextField;

    public FestoNodeView(Style style) {
        this.style = style;
    }

    @Override
    public void buildUI(JPanel jPanel, final ContributionProvider<FestoNodeContribution> provider) {
        jPanel.setLayout(new BoxLayout(jPanel, BoxLayout.Y_AXIS));
        jPanel.add(createVerticalSpacing(style.getVerticalSpacing()));
        jPanel.add(createInput(provider));
        jPanel.add(createVerticalSpacing(style.getExtraLargeVerticalSpacing()));
    }

    private Box createInput(final ContributionProvider<FestoNodeContribution> provider) {
        Box inputBox = Box.createHorizontalBox();
        inputBox.setAlignmentX(Component.LEFT_ALIGNMENT);
        inputBox.add(new JLabel("Move by:"));
        inputBox.add(createHorizontalSpacing());

        jTextField = new JTextField();
        jTextField.setFocusable(false);
        jTextField.setPreferredSize(style.getInputfieldSize());
        jTextField.setMaximumSize(jTextField.getPreferredSize());
        jTextField.addMouseListener(new MouseAdapter() {
            @Override
            public void mousePressed(MouseEvent e) {
                KeyboardNumberInput keyboardInput = provider.get().getKeyboardForTextField();
                keyboardInput.show(jTextField, provider.get().getCallbackForTextField());
            }
        });

        inputBox.add(jTextField);
        return inputBox;
    }

    private Component createVerticalSpacing(int height) {
        return Box.createRigidArea(new Dimension(0, height));
    }

    private Component createHorizontalSpacing() {
        return Box.createRigidArea(new Dimension(style.getHorizontalSpacing(), 0));
    }

    public void setValue(Integer value) {
        jTextField.setText(value.toString());
    }

    public Integer getValue() {
        return Integer.parseInt(jTextField.getText());
    }
}
